searchData={"items":[{"type":"module","title":"Bingex","doc":"Bingex is an Elixir library for interacting with the BingX exchange, providing a transparent and reliable API interface.\n\nThis library offers:\n  - **HTTP API support** for `Swap` and `User` scopes.\n  - **Sockets** for real-time WebSocket price updates and event streaming.\n  - **Validated models** to ensure data reliability.\n  - **Transparent request-response handling**, exposing full exchange responses for independent interpretation.","ref":"Bingex.html"},{"type":"module","title":"Placing an Order - Bingex","doc":"To place an order on the BingX Swap market:\n\n```elixir\nalias Bingex.{Order, Swap}\n\napi_key = \"YOUR_API_KEY\"\nsecret_key = \"YOUR_SECRET_KEY\"\n\norder = %Order{\n  symbol: \"BTC-USDT\",\n  side: :buy,\n  type: :market,\n  price: 65000,\n  quantity: 0.01\n}\n\ncase Swap.create_order(order, api_key, secret_key) do\n  {:ok, response, _meta} -> IO.inspect(response, label: \"Order Placed\")\n  {:error, error, _meta} -> IO.inspect(error, label: \"Order Failed\")\nend\n```","ref":"Bingex.html#module-placing-an-order"},{"type":"module","title":"Fetching SWAP Balance - Bingex","doc":"To retrieve user balances:\n```elixir\nalias Bingex.Swap\n\ncase Swap.get_balance(api_key, secret_key) do\n  {:ok, balance, _meta} -> IO.inspect(balance, label: \"Account Balance\")\n  {:error, error, _meta} -> IO.inspect(error, label: \"Balance Fetch Failed\")\nend\n```","ref":"Bingex.html#module-fetching-swap-balance"},{"type":"module","title":"Sockets - Bingex","doc":"Define and start your WebSocket using Socket implementation (e.g. `Bingex.Swap.PriceSocket`):\n```elixir\ndefmodule PriceSource do\n  use Bingex.Swap.PriceSocket\n  alias Bingex.Swap.PriceSocket\n\n  def start_link(_args \\\\ []) do\n    PriceSocket.start_link(__MODULE__, :state)\n  end\n\n  @impl true\n  def handle_connect(state) do\n    PriceSocket.subscribe(%{symbol: \"BTC-USDT\", type: :last})\n    {:ok, state}\n  end\n\n  @impl true\n  def handle_event(type, event, state) do\n    IO.inspect({type, event, state})\n    {:ok, state}\n  end\nend\n\nPriceSource.start_link() \n```","ref":"Bingex.html#module-sockets"},{"type":"module","title":"Transparency and Reliability - Bingex","doc":"Bingex ensures that all API responses remain fully accessible with a really tiny abstraction, allowing users to interpret and validate responses as needed. The library follows a simple but pragmatic approach, ensuring secure and predictable request handling.","ref":"Bingex.html#module-transparency-and-reliability"},{"type":"module","title":"Bingex.API.Reply","doc":"Represents a standardized API response from BingX.\n\nThis module defines a structured format for API replies, including \na status code, message, data payload, and optional additional fields.\nIt provides utilities to manipulate response data.","ref":"Bingex.API.Reply.html"},{"type":"type","title":"Bingex.API.Reply.code/0","doc":"","ref":"Bingex.API.Reply.html#t:code/0"},{"type":"type","title":"Bingex.API.Reply.data/0","doc":"","ref":"Bingex.API.Reply.html#t:data/0"},{"type":"type","title":"Bingex.API.Reply.message/0","doc":"","ref":"Bingex.API.Reply.html#t:message/0"},{"type":"function","title":"Bingex.API.Reply.put_data/2","doc":"","ref":"Bingex.API.Reply.html#put_data/2"},{"type":"type","title":"Bingex.API.Reply.t/0","doc":"","ref":"Bingex.API.Reply.html#t:t/0"},{"type":"type","title":"Bingex.API.Reply.t/1","doc":"","ref":"Bingex.API.Reply.html#t:t/1"},{"type":"module","title":"Bingex.Convertors","doc":"This module provides encoders/encoders to perform conversions \nfrom local terms to BingX API terms, and vice versa.","ref":"Bingex.Convertors.html"},{"type":"function","title":"Bingex.Convertors.decode_margin_mode/1","doc":"","ref":"Bingex.Convertors.html#decode_margin_mode/1"},{"type":"function","title":"Bingex.Convertors.decode_order_execution_type/1","doc":"","ref":"Bingex.Convertors.html#decode_order_execution_type/1"},{"type":"function","title":"Bingex.Convertors.decode_order_side/1","doc":"","ref":"Bingex.Convertors.html#decode_order_side/1"},{"type":"function","title":"Bingex.Convertors.decode_order_status/1","doc":"","ref":"Bingex.Convertors.html#decode_order_status/1"},{"type":"function","title":"Bingex.Convertors.decode_order_type/1","doc":"","ref":"Bingex.Convertors.html#decode_order_type/1"},{"type":"function","title":"Bingex.Convertors.decode_position_side/1","doc":"","ref":"Bingex.Convertors.html#decode_position_side/1"},{"type":"function","title":"Bingex.Convertors.decode_working_type/1","doc":"","ref":"Bingex.Convertors.html#decode_working_type/1"},{"type":"function","title":"Bingex.Convertors.encode_margin_mode/1","doc":"","ref":"Bingex.Convertors.html#encode_margin_mode/1"},{"type":"function","title":"Bingex.Convertors.encode_order_side/1","doc":"","ref":"Bingex.Convertors.html#encode_order_side/1"},{"type":"function","title":"Bingex.Convertors.encode_order_type/1","doc":"","ref":"Bingex.Convertors.html#encode_order_type/1"},{"type":"function","title":"Bingex.Convertors.encode_position_side/1","doc":"","ref":"Bingex.Convertors.html#encode_position_side/1"},{"type":"function","title":"Bingex.Convertors.encode_working_type/1","doc":"","ref":"Bingex.Convertors.html#encode_working_type/1"},{"type":"function","title":"Bingex.Convertors.to_abs/1","doc":"","ref":"Bingex.Convertors.html#to_abs/1"},{"type":"function","title":"Bingex.Convertors.to_binary/1","doc":"","ref":"Bingex.Convertors.html#to_binary/1"},{"type":"function","title":"Bingex.Convertors.to_binary_unless/2","doc":"","ref":"Bingex.Convertors.html#to_binary_unless/2"},{"type":"function","title":"Bingex.Convertors.to_boolean/1","doc":"","ref":"Bingex.Convertors.html#to_boolean/1"},{"type":"function","title":"Bingex.Convertors.to_float/1","doc":"","ref":"Bingex.Convertors.html#to_float/1"},{"type":"function","title":"Bingex.Convertors.to_integer/1","doc":"","ref":"Bingex.Convertors.html#to_integer/1"},{"type":"function","title":"Bingex.Convertors.to_non_empty_binary/1","doc":"","ref":"Bingex.Convertors.html#to_non_empty_binary/1"},{"type":"function","title":"Bingex.Convertors.to_non_neg_integer/1","doc":"","ref":"Bingex.Convertors.html#to_non_neg_integer/1"},{"type":"module","title":"Bingex.HTTP.Adapter","doc":"HTTP adapter for making requests to the BingX API.\n\nThis module handles HTTP requests using `Finch`, transforming `Bingex.HTTP.Request`\ninto actual API calls and converting responses into structured `Bingex.HTTP.Response` \nor `Bingex.HTTP.Error` results.","ref":"Bingex.HTTP.Adapter.html"},{"type":"function","title":"Bingex.HTTP.Adapter.request/1","doc":"","ref":"Bingex.HTTP.Adapter.html#request/1"},{"type":"module","title":"Bingex.HTTP.Request","doc":"Constructs and signs HTTP requests for the BingX API.\n\nThis module provides utilities for creating HTTP requests, adding authentication headers, \nand signing parameters when required. It also supports URL building with query parameters \nand timestamping to ensure request validity.","ref":"Bingex.HTTP.Request.html"},{"type":"function","title":"Bingex.HTTP.Request.auth_headers/2","doc":"","ref":"Bingex.HTTP.Request.html#auth_headers/2"},{"type":"type","title":"Bingex.HTTP.Request.body/0","doc":"","ref":"Bingex.HTTP.Request.html#t:body/0"},{"type":"function","title":"Bingex.HTTP.Request.build_url/3","doc":"","ref":"Bingex.HTTP.Request.html#build_url/3"},{"type":"type","title":"Bingex.HTTP.Request.headers/0","doc":"","ref":"Bingex.HTTP.Request.html#t:headers/0"},{"type":"type","title":"Bingex.HTTP.Request.method/0","doc":"","ref":"Bingex.HTTP.Request.html#t:method/0"},{"type":"function","title":"Bingex.HTTP.Request.new/4","doc":"","ref":"Bingex.HTTP.Request.html#new/4"},{"type":"type","title":"Bingex.HTTP.Request.options/0","doc":"","ref":"Bingex.HTTP.Request.html#t:options/0"},{"type":"type","title":"Bingex.HTTP.Request.params/0","doc":"","ref":"Bingex.HTTP.Request.html#t:params/0"},{"type":"type","title":"Bingex.HTTP.Request.path/0","doc":"","ref":"Bingex.HTTP.Request.html#t:path/0"},{"type":"function","title":"Bingex.HTTP.Request.set_recv_window/2","doc":"","ref":"Bingex.HTTP.Request.html#set_recv_window/2"},{"type":"function","title":"Bingex.HTTP.Request.set_signature/2","doc":"","ref":"Bingex.HTTP.Request.html#set_signature/2"},{"type":"function","title":"Bingex.HTTP.Request.set_timestamp/1","doc":"","ref":"Bingex.HTTP.Request.html#set_timestamp/1"},{"type":"type","title":"Bingex.HTTP.Request.t/0","doc":"","ref":"Bingex.HTTP.Request.html#t:t/0"},{"type":"type","title":"Bingex.HTTP.Request.url/0","doc":"","ref":"Bingex.HTTP.Request.html#t:url/0"},{"type":"module","title":"Bingex.HTTP.Response","doc":"Represents an HTTP response from the BingX API.\n\nThis module defines a structured format for handling HTTP responses, \nincluding the status code, headers, and response body.","ref":"Bingex.HTTP.Response.html"},{"type":"type","title":"Bingex.HTTP.Response.t/0","doc":"","ref":"Bingex.HTTP.Response.html#t:t/0"},{"type":"module","title":"Bingex.HTTP.Signature","doc":"Handles request signing for the BingX API.\n\nThis module provides functions to generate HMAC-SHA256 signatures for \nauthenticated API requests. It serializes parameters and computes the \ncryptographic hash using a provided secret key.","ref":"Bingex.HTTP.Signature.html"},{"type":"function","title":"Bingex.HTTP.Signature.generate/2","doc":"","ref":"Bingex.HTTP.Signature.html#generate/2"},{"type":"function","title":"Bingex.HTTP.Signature.hash/2","doc":"","ref":"Bingex.HTTP.Signature.html#hash/2"},{"type":"function","title":"Bingex.HTTP.Signature.serialize/1","doc":"","ref":"Bingex.HTTP.Signature.html#serialize/1"},{"type":"module","title":"Bingex.Order","doc":"Defines the structure and types for orders in BingX.\n\nThis module provides the `Bingex.Order` struct along with associated types \nfor order properties such as type, status, side, position side, and margin mode. \nIt also includes functions to create and validate orders.","ref":"Bingex.Order.html"},{"type":"type","title":"Bingex.Order.execution_type/0","doc":"","ref":"Bingex.Order.html#t:execution_type/0"},{"type":"type","title":"Bingex.Order.margin_mode/0","doc":"","ref":"Bingex.Order.html#t:margin_mode/0"},{"type":"function","title":"Bingex.Order.new/1","doc":"Creates `Bingex.Order` struct using the provided parameters.\nNote that it only performs validation for the specified values, \nleaving `nil` for the rest.","ref":"Bingex.Order.html#new/1"},{"type":"function","title":"Bingex.Order.new!/1","doc":"The same as new/1 but returns struct and raises error instead of tuples.","ref":"Bingex.Order.html#new!/1"},{"type":"type","title":"Bingex.Order.position_side/0","doc":"","ref":"Bingex.Order.html#t:position_side/0"},{"type":"type","title":"Bingex.Order.side/0","doc":"","ref":"Bingex.Order.html#t:side/0"},{"type":"type","title":"Bingex.Order.status/0","doc":"","ref":"Bingex.Order.html#t:status/0"},{"type":"type","title":"Bingex.Order.t/0","doc":"Represents an order in BingX.\n\nFields:\n  - `type` - The type of order (e.g., market, limit, stop-loss).\n  - `symbol` - The trading pair symbol.\n  - `side` - The order side, either `:buy` or `:sell`.\n  - `position_side` - Specifies whether the position is `:long`, `:short`, or `:both`.\n  - `quantity` - The amount of the asset to be traded.\n  - `price` - The order price.\n  - `stop_price` - The stop price for stop-loss or take-profit orders.\n  - `working_type` - The price type used (`:mark_price`, `:index_price`, or `:contract_price`).","ref":"Bingex.Order.html#t:t/0"},{"type":"type","title":"Bingex.Order.type/0","doc":"","ref":"Bingex.Order.html#t:type/0"},{"type":"type","title":"Bingex.Order.working_type/0","doc":"","ref":"Bingex.Order.html#t:working_type/0"},{"type":"behaviour","title":"Bingex.Socket","doc":"Provides an abstraction over WebSocket connections for BingX.\n\nThis module builds on `WebSockex`, handling connection management, message passing, \nand event dispatching while hiding implementation details. It allows consumers to define\ntheir own event handlers through callback functions.\n\nKey features:\n  - Automatic handling of WebSocket connections, including reconnections.\n  - Message passing using `call/3`, `cast/2`, and `send/2`.\n  - Support for compressed binary frames (e.g., handling gzip-compressed data).\n  - Flexible event handling via callback functions.\n\nThis module is designed to simplify WebSocket integration while allowing customization\nthrough user-defined modules.","ref":"Bingex.Socket.html"},{"type":"function","title":"Bingex.Socket.call/3","doc":"Sends a synchronous message.","ref":"Bingex.Socket.html#call/3"},{"type":"function","title":"Bingex.Socket.cast/2","doc":"Sends an asynchronous message.","ref":"Bingex.Socket.html#cast/2"},{"type":"type","title":"Bingex.Socket.event/0","doc":"","ref":"Bingex.Socket.html#t:event/0"},{"type":"callback","title":"Bingex.Socket.handle_call/3","doc":"","ref":"Bingex.Socket.html#c:handle_call/3"},{"type":"callback","title":"Bingex.Socket.handle_cast/2","doc":"","ref":"Bingex.Socket.html#c:handle_cast/2"},{"type":"callback","title":"Bingex.Socket.handle_connect/1","doc":"","ref":"Bingex.Socket.html#c:handle_connect/1"},{"type":"callback","title":"Bingex.Socket.handle_disconnect/2","doc":"","ref":"Bingex.Socket.html#c:handle_disconnect/2"},{"type":"callback","title":"Bingex.Socket.handle_event/2","doc":"","ref":"Bingex.Socket.html#c:handle_event/2"},{"type":"callback","title":"Bingex.Socket.handle_info/2","doc":"","ref":"Bingex.Socket.html#c:handle_info/2"},{"type":"type","title":"Bingex.Socket.message/0","doc":"","ref":"Bingex.Socket.html#t:message/0"},{"type":"function","title":"Bingex.Socket.send/2","doc":"Sends a message to the process to the specified PID.","ref":"Bingex.Socket.html#send/2"},{"type":"function","title":"Bingex.Socket.start/4","doc":"Starts a WebSocket process.","ref":"Bingex.Socket.html#start/4"},{"type":"function","title":"Bingex.Socket.start_link/4","doc":"Starts a WebSocket process linked to the current process.","ref":"Bingex.Socket.html#start_link/4"},{"type":"type","title":"Bingex.Socket.state/0","doc":"","ref":"Bingex.Socket.html#t:state/0"},{"type":"function","title":"Bingex.Socket.whereis/1","doc":"Returns the `pid` of a Socket process, `nil` otherwise.","ref":"Bingex.Socket.html#whereis/1"},{"type":"module","title":"Bingex.Swap","doc":"Provides an interface to interact with the BingX Swap API.\n\nThis module allows users to perform various trading operations, including placing orders, retrieving account balances, managing leverage, and querying market data. It handles authentication, request signing, and response processing to ensure seamless communication with the BingX Swap API.\n\nKey features:\n  - Place and test orders\n  - Manage positions and leverage settings\n  - Retrieve account balances and order history\n  - Fetch market data, contracts, and quotes\n  - Query server time for request synchronization\n\nAll requests requiring authentication will be signed using an API key and secret key.","ref":"Bingex.Swap.html"},{"type":"function","title":"Bingex.Swap.close_all_positions/3","doc":"Request to close all positions by market symbol (ex. BTC-USDT) with account credentials.","ref":"Bingex.Swap.html#close_all_positions/3"},{"type":"function","title":"Bingex.Swap.get_balance/2","doc":"Requests to get current swap balance.","ref":"Bingex.Swap.html#get_balance/2"},{"type":"function","title":"Bingex.Swap.get_contracts/1","doc":"","ref":"Bingex.Swap.html#get_contracts/1"},{"type":"function","title":"Bingex.Swap.get_orders_history/6","doc":"Request to get all user's orders (pending, active, ...) by an optional \nperiod (start_time, end_time) and an optional limit of returned amount \nof orders with account credentials.","ref":"Bingex.Swap.html#get_orders_history/6"},{"type":"function","title":"Bingex.Swap.get_quotes/1","doc":"","ref":"Bingex.Swap.html#get_quotes/1"},{"type":"function","title":"Bingex.Swap.get_server_time/0","doc":"Requests to get current server time.","ref":"Bingex.Swap.html#get_server_time/0"},{"type":"function","title":"Bingex.Swap.place_order/3","doc":"Requests to place an order using order data with account credentials.","ref":"Bingex.Swap.html#place_order/3"},{"type":"function","title":"Bingex.Swap.place_orders/3","doc":"Requests to place bunch of orders using list of order data with account credentials.","ref":"Bingex.Swap.html#place_orders/3"},{"type":"function","title":"Bingex.Swap.place_test_order/3","doc":"Requests to place a test order using order data with account credentials.","ref":"Bingex.Swap.html#place_test_order/3"},{"type":"function","title":"Bingex.Swap.set_leverage/5","doc":"Request to set user's leverage amount by market symbol, position side and account credentials.\nPosition side can be either `:crossed` or `:isolated`.\nCurrently, BingX allows leverage from 1 to 125.","ref":"Bingex.Swap.html#set_leverage/5"},{"type":"function","title":"Bingex.Swap.set_margin_mode/4","doc":"Request to set user's margin mode by market symbol and account credentials.\nMargin mode can be either `:crossed` or `:isolated`.","ref":"Bingex.Swap.html#set_margin_mode/4"},{"type":"module","title":"Bingex.Swap.AccountEvent","doc":"Represents an account event in BingX swaps.\n\nHandles order, funding fee, deposit, and withdrawal events, extracting wallet and position updates.","ref":"Bingex.Swap.AccountEvent.html"},{"type":"function","title":"Bingex.Swap.AccountEvent.decode/1","doc":"","ref":"Bingex.Swap.AccountEvent.html#decode/1"},{"type":"type","title":"Bingex.Swap.AccountEvent.event_type/0","doc":"","ref":"Bingex.Swap.AccountEvent.html#t:event_type/0"},{"type":"type","title":"Bingex.Swap.AccountEvent.t/0","doc":"","ref":"Bingex.Swap.AccountEvent.html#t:t/0"},{"type":"module","title":"Bingex.Swap.CloseAllPositionsData","doc":"Parses and structures response data for closing all swap positions on BingX.\n\nThis module extracts and formats the list of successfully and unsuccessfully closed positions \nfrom API responses. It also provides a utility to embed the parsed data into a `Bingex.API.Reply`.","ref":"Bingex.Swap.CloseAllPositionsData.html"},{"type":"function","title":"Bingex.Swap.CloseAllPositionsData.decode/1","doc":"","ref":"Bingex.Swap.CloseAllPositionsData.html#decode/1"},{"type":"function","title":"Bingex.Swap.CloseAllPositionsData.embed_in_reply/1","doc":"","ref":"Bingex.Swap.CloseAllPositionsData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.CloseAllPositionsData.t/0","doc":"","ref":"Bingex.Swap.CloseAllPositionsData.html#t:t/0"},{"type":"module","title":"Bingex.Swap.ConfigEvent","doc":"Represents a configuration event in BingX swaps.\n\nIncludes margin mode, leverage settings, and symbol details.","ref":"Bingex.Swap.ConfigEvent.html"},{"type":"function","title":"Bingex.Swap.ConfigEvent.decode/1","doc":"","ref":"Bingex.Swap.ConfigEvent.html#decode/1"},{"type":"type","title":"Bingex.Swap.ConfigEvent.t/0","doc":"","ref":"Bingex.Swap.ConfigEvent.html#t:t/0"},{"type":"module","title":"Bingex.Swap.ContractInfo","doc":"Represents contract information for a swap contract in BingX.\n\nThis module provides structured details about a swap contract, including precision settings, \ntrading fees, status, and lifecycle timestamps.","ref":"Bingex.Swap.ContractInfo.html"},{"type":"type","title":"Bingex.Swap.ContractInfo.contract_status/0","doc":"","ref":"Bingex.Swap.ContractInfo.html#t:contract_status/0"},{"type":"function","title":"Bingex.Swap.ContractInfo.decode/1","doc":"","ref":"Bingex.Swap.ContractInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.ContractInfo.t/0","doc":"Contract (market) information.\n\nFields:\n  - `contract_id` (binary): Unique identifier for the contract.\n  - `symbol` (binary): Trading pair symbol (e.g., \"BTC-USDT\").\n  - `quantity_precision` (integer): Precision of order quantity.\n  - `price_precision` (integer): Precision of price values.\n  - `taker_fee_rate` (float): Taker fee rate as a percentage.\n  - `maker_fee_rate` (float): Maker fee rate as a percentage.\n  - `min_quantity` (float): Minimum order quantity.\n  - `min_quote_amount` (float): Minimum order value in quote currency.\n  - `currency` (binary): Settlement currency (e.g., \"USDT\").\n  - `asset` (binary): Base asset of the contract.\n  - `status` (`contract_status()`): Current contract status (`:online`, `:pre_online`, `:offline`, `:forbidden`).\n  - `opening_status` (boolean): Whether trading is open.\n  - `closing_status` (boolean): Whether closing of positions is allowed.\n  - `guaranteed_stop_status` (boolean): Whether guaranteed stop-loss is available.\n  - `guaranteed_stop_fee_rate` (float): Fee rate for guaranteed stop-loss.\n  - `transactions_status` (boolean): Whether contract transactions are enabled.\n  - `launch_time` (non_neg_integer): Timestamp of contract launch.\n  - `maintain_time` (non_neg_integer): Timestamp of next maintenance.\n  - `off_time` (non_neg_integer): Timestamp when contract will be taken offline.","ref":"Bingex.Swap.ContractInfo.html#t:t/0"},{"type":"module","title":"Bingex.Swap.DetailedOrderInfo","doc":"Represents detailed order information for a swap contract in BingX.\n\nThis module provides a structured representation of an order's full details, including \nexecution status, fees, profit/loss, and associated risk management parameters.","ref":"Bingex.Swap.DetailedOrderInfo.html"},{"type":"function","title":"Bingex.Swap.DetailedOrderInfo.decode/1","doc":"Complete order information.\n\nFields:\n  - `order_id` (binary): Unique identifier for the order.\n  - `symbol` (binary): Trading pair symbol (e.g., \"BTC-USDT\").\n  - `side` (`Order.side()`): Buy/Sell direction of the order.\n  - `position_side` (`Order.position_side()`): Position type (e.g., `long`, `short`).\n  - `status` (`Order.status()`): Current status of the order (e.g., `filled`, `canceled`).\n  - `stop_price` (float): Stop price for conditional orders.\n  - `price` (float): Price at which the order was placed.\n  - `type` (`Order.type()`): Order type (e.g., `market`, `limit`).\n  - `client_order_id` (binary): Custom client-provided order ID.\n  - `trigger_order_id` (binary | nil): ID of the trigger order (if applicable).\n  - `working_type` (`Order.working_type()`): Price type used for stop orders.\n  - `leverage` (integer): Leverage level applied to the order.\n  - `fee` (float): Trading fee incurred.\n  - `executed_quote_amount` (float): Total executed quote asset amount.\n  - `executed_quantity` (float): Total executed base asset quantity.\n  - `only_one_position?` (boolean): Whether the order allows only one position.\n  - `order_type` (binary): Additional classification of the order type.\n  - `original_quantity` (float): Initial order quantity.\n  - `average_price` (float): Average execution price of the order.\n  - `position_id` (binary | nil): Associated position ID.\n  - `profit` (float): Realized profit from the order.\n  - `reduce_only?` (boolean): Whether the order reduces an existing position.\n  - `stop_loss` (map | nil): Stop-loss details (if applicable).\n  - `stop_loss_entrust_price` (float): Price at which stop-loss is triggered.\n  - `take_profit` (map | nil): Take-profit details (if applicable).\n  - `take_profit_entrust_price` (float): Price at which take-profit is triggered.\n  - `stop_guaranteed?` (boolean): Whether stop-loss is guaranteed.\n  - `timestamp` (non_neg_integer): Order creation timestamp.\n  - `update_time` (non_neg_integer): Last update timestamp.","ref":"Bingex.Swap.DetailedOrderInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.DetailedOrderInfo.t/0","doc":"","ref":"Bingex.Swap.DetailedOrderInfo.html#t:t/0"},{"type":"behaviour","title":"Bingex.Swap.EventSocket","doc":"```elixir    \ndefmodule EventSource do\n  use Bingex.Swap.EventSocket\n  require Logger\n\n  alias Bingex.Swap.EventSocket\n  alias Bingex.User\n\n  def start_link(listen_key) do\n    EventSocket.start_link(listen_key, __MODULE__, :state)\n  end\n\n  @impl true\n  def handle_event(type, event, state) do\n    Logger.info(%{ type: type, event: event, state: state })\n    {:ok, state}\n  end\nend\n```","ref":"Bingex.Swap.EventSocket.html"},{"type":"function","title":"Bingex.Swap.EventSocket.call/3","doc":"","ref":"Bingex.Swap.EventSocket.html#call/3"},{"type":"function","title":"Bingex.Swap.EventSocket.cast/2","doc":"","ref":"Bingex.Swap.EventSocket.html#cast/2"},{"type":"callback","title":"Bingex.Swap.EventSocket.handle_event/3","doc":"","ref":"Bingex.Swap.EventSocket.html#c:handle_event/3"},{"type":"function","title":"Bingex.Swap.EventSocket.start/4","doc":"","ref":"Bingex.Swap.EventSocket.html#start/4"},{"type":"function","title":"Bingex.Swap.EventSocket.start_link/4","doc":"","ref":"Bingex.Swap.EventSocket.html#start_link/4"},{"type":"module","title":"Bingex.Swap.GetBalanceData","doc":"Parses and structures balance data for BingX swap accounts.\n\nThis module extracts asset balance information from API responses, \nconverting raw data into a structured format using `Bingex.Swap.Models.BalanceInfo`. \nIt also provides a utility to embed the parsed data into a `Bingex.API.Reply`.","ref":"Bingex.Swap.GetBalanceData.html"},{"type":"function","title":"Bingex.Swap.GetBalanceData.decode/1","doc":"","ref":"Bingex.Swap.GetBalanceData.html#decode/1"},{"type":"function","title":"Bingex.Swap.GetBalanceData.embed_in_reply/1","doc":"","ref":"Bingex.Swap.GetBalanceData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.GetBalanceData.t/0","doc":"","ref":"Bingex.Swap.GetBalanceData.html#t:t/0"},{"type":"module","title":"Bingex.Swap.GetContractsData","doc":"Parses and structures contract data for BingX swap markets.\n\nConverts raw API response data into a list of `Bingex.Swap.ContractInfo` structs \nand embeds the parsed data into a `Bingex.API.Reply`.","ref":"Bingex.Swap.GetContractsData.html"},{"type":"function","title":"Bingex.Swap.GetContractsData.decode/1","doc":"","ref":"Bingex.Swap.GetContractsData.html#decode/1"},{"type":"function","title":"Bingex.Swap.GetContractsData.embed_in_reply/1","doc":"","ref":"Bingex.Swap.GetContractsData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.GetContractsData.t/0","doc":"","ref":"Bingex.Swap.GetContractsData.html#t:t/0"},{"type":"module","title":"Bingex.Swap.GetOrdersHistoryData","doc":"Parses and structures historical order data for BingX swaps.\n\nConverts raw API response data into a list of `Bingex.Swap.DetailedOrderInfo` structs \nand embeds the parsed data into a `Bingex.API.Reply`.","ref":"Bingex.Swap.GetOrdersHistoryData.html"},{"type":"function","title":"Bingex.Swap.GetOrdersHistoryData.decode/1","doc":"","ref":"Bingex.Swap.GetOrdersHistoryData.html#decode/1"},{"type":"function","title":"Bingex.Swap.GetOrdersHistoryData.embed_in_reply/1","doc":"","ref":"Bingex.Swap.GetOrdersHistoryData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.GetOrdersHistoryData.t/0","doc":"","ref":"Bingex.Swap.GetOrdersHistoryData.html#t:t/0"},{"type":"module","title":"Bingex.Swap.GetQuotesData","doc":"Parses and structures quote data for BingX swaps.\n\nConverts raw API response data into a list of `Bingex.Swap.QuoteInfo` structs \nand embeds the parsed data into a `Bingex.API.Reply`.","ref":"Bingex.Swap.GetQuotesData.html"},{"type":"function","title":"Bingex.Swap.GetQuotesData.decode/1","doc":"","ref":"Bingex.Swap.GetQuotesData.html#decode/1"},{"type":"function","title":"Bingex.Swap.GetQuotesData.embed_in_reply/1","doc":"","ref":"Bingex.Swap.GetQuotesData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.GetQuotesData.t/0","doc":"","ref":"Bingex.Swap.GetQuotesData.html#t:t/0"},{"type":"module","title":"Bingex.Swap.GetServerTimeData","doc":"Parses and structures server time data for BingX swaps.\n\nExtracts the server time from the API response and embeds it into a `Bingex.API.Reply`.","ref":"Bingex.Swap.GetServerTimeData.html"},{"type":"function","title":"Bingex.Swap.GetServerTimeData.decode/1","doc":"","ref":"Bingex.Swap.GetServerTimeData.html#decode/1"},{"type":"function","title":"Bingex.Swap.GetServerTimeData.embed_in_reply/1","doc":"","ref":"Bingex.Swap.GetServerTimeData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.GetServerTimeData.t/0","doc":"","ref":"Bingex.Swap.GetServerTimeData.html#t:t/0"},{"type":"module","title":"Bingex.Swap.Marshal","doc":"Handles serialization and transformation of orders for BingX Swap.\n\nThis module ensures that order structures are properly formatted and adapted \nfor API communication, converting internal representations into the expected \nserialized formats.","ref":"Bingex.Swap.Marshal.html"},{"type":"function","title":"Bingex.Swap.Marshal.serialize_order/1","doc":"","ref":"Bingex.Swap.Marshal.html#serialize_order/1"},{"type":"function","title":"Bingex.Swap.Marshal.serialize_orders/1","doc":"","ref":"Bingex.Swap.Marshal.html#serialize_orders/1"},{"type":"function","title":"Bingex.Swap.Marshal.transform_order/1","doc":"","ref":"Bingex.Swap.Marshal.html#transform_order/1"},{"type":"module","title":"Bingex.Swap.Models.BalanceInfo","doc":"Represents balance information for a BingX swap account.\n\nThis module provides structured details about a user's account balance, including margin availability, \nequity, and profit/loss metrics.","ref":"Bingex.Swap.Models.BalanceInfo.html"},{"type":"function","title":"Bingex.Swap.Models.BalanceInfo.decode/1","doc":"","ref":"Bingex.Swap.Models.BalanceInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.Models.BalanceInfo.t/0","doc":"User's balance information.\n\nFields:\n  - `asset` (binary): The asset type (e.g., \"USDT\").\n  - `balance` (float): Total balance of the account.\n  - `available_margin` (float): Margin available for trading.\n  - `equity` (float): Total equity value.\n  - `freezed_margin` (float): Margin currently locked in open positions.\n  - `realized_profit` (float): Profit or loss from closed positions.\n  - `unrealized_profit` (float): Profit or loss from open positions.\n  - `used_margin` (float): Margin currently in use.\n  - `user_id` (binary): Unique identifier of the user.\n  - `uid` (binary): Shortened user identifier.","ref":"Bingex.Swap.Models.BalanceInfo.html#t:t/0"},{"type":"module","title":"Bingex.Swap.OrderInfo","doc":"Represents order information for a swap contract in BingX.\n\nThis module provides a structured representation of an order, including its type, status, \nrisk management settings, and execution parameters.","ref":"Bingex.Swap.OrderInfo.html"},{"type":"function","title":"Bingex.Swap.OrderInfo.decode/1","doc":"","ref":"Bingex.Swap.OrderInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.OrderInfo.t/0","doc":"Basic order information.\n\nFields:\n  - `symbol` (binary): Trading pair symbol (e.g., \"BTC-USDT\").\n  - `side` (`Order.side()`): Buy/Sell direction of the order.\n  - `position_side` (`Order.position_side()`): Position type (e.g., `long`, `short`).\n  - `price` (float): Price at which the order was placed.\n  - `stop_price` (float): Stop price for conditional orders.\n  - `working_type` (`Order.working_type()`): Price type used for stop orders.\n  - `quantity` (float): Order quantity.\n  - `type` (`Order.type()`): Order type (e.g., `market`, `limit`).\n  - `order_id` (binary): Unique identifier for the order.\n  - `client_order_id` (binary): Custom client-provided order ID.\n  - `stop_loss` (map | nil): Stop-loss details (if applicable).\n  - `take_profit` (map | nil): Take-profit details (if applicable).\n  - `time_in_force` (any): Order expiration setting.\n  - `reduce_only?` (boolean): Whether the order reduces an existing position.\n  - `price_rate` (float): Rate used for price calculations.\n  - `activation_price` (float): Activation price for certain conditional orders.\n  - `close_position?` (boolean): Whether the order closes an entire position.\n  - `stop_guaranteed?` (boolean): Whether stop-loss is guaranteed.","ref":"Bingex.Swap.OrderInfo.html#t:t/0"},{"type":"module","title":"Bingex.Swap.PlaceOrderData","doc":"Parses and structures order placement data for BingX swaps.\n\nConverts raw API response data into a `Bingex.Swap.OrderInfo` struct \nand embeds it into a `Bingex.API.Reply`.","ref":"Bingex.Swap.PlaceOrderData.html"},{"type":"function","title":"Bingex.Swap.PlaceOrderData.decode/1","doc":"","ref":"Bingex.Swap.PlaceOrderData.html#decode/1"},{"type":"function","title":"Bingex.Swap.PlaceOrderData.embed_in_reply/1","doc":"","ref":"Bingex.Swap.PlaceOrderData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.PlaceOrderData.t/0","doc":"","ref":"Bingex.Swap.PlaceOrderData.html#t:t/0"},{"type":"module","title":"Bingex.Swap.PlaceOrdersData","doc":"Parses and structures batch order placement data for BingX swaps.\n\nConverts raw API response data into a list of `Bingex.Swap.OrderInfo` structs \nand embeds them into a `Bingex.API.Reply`.","ref":"Bingex.Swap.PlaceOrdersData.html"},{"type":"function","title":"Bingex.Swap.PlaceOrdersData.decode/1","doc":"","ref":"Bingex.Swap.PlaceOrdersData.html#decode/1"},{"type":"function","title":"Bingex.Swap.PlaceOrdersData.embed_in_reply/1","doc":"","ref":"Bingex.Swap.PlaceOrdersData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.PlaceOrdersData.t/0","doc":"","ref":"Bingex.Swap.PlaceOrdersData.html#t:t/0"},{"type":"module","title":"Bingex.Swap.PlaceTestOrderData","doc":"Parses and structures test order placement data for BingX swaps.\n\nConverts raw API response data into a `Bingex.Swap.OrderInfo` struct \nand embeds it into a `Bingex.API.Reply`.","ref":"Bingex.Swap.PlaceTestOrderData.html"},{"type":"function","title":"Bingex.Swap.PlaceTestOrderData.decode/1","doc":"","ref":"Bingex.Swap.PlaceTestOrderData.html#decode/1"},{"type":"function","title":"Bingex.Swap.PlaceTestOrderData.embed_in_reply/1","doc":"","ref":"Bingex.Swap.PlaceTestOrderData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.PlaceTestOrderData.t/0","doc":"","ref":"Bingex.Swap.PlaceTestOrderData.html#t:t/0"},{"type":"module","title":"Bingex.Swap.PositionUpdate","doc":"Represents position update information for a swap contract in BingX (ws event).\n\nThis module provides a structured representation of real-time position updates, \nincluding margin details, profit/loss, and pricing information.","ref":"Bingex.Swap.PositionUpdate.html"},{"type":"function","title":"Bingex.Swap.PositionUpdate.decode/1","doc":"","ref":"Bingex.Swap.PositionUpdate.html#decode/1"},{"type":"type","title":"Bingex.Swap.PositionUpdate.t/0","doc":"Position update information.\n\nFields:\n  - `side` (`Order.position_side()`): Position type (e.g., `long`, `short`).\n  - `symbol` (binary): Trading pair symbol (e.g., \"BTC-USDT\").\n  - `margin` (float): Initial margin allocated to the position.\n  - `position_margin` (float): Current margin assigned to the position.\n  - `average_price` (float): Average entry price of the position.\n  - `unrealized_pnl` (float): Unrealized profit or loss.\n  - `realized_pnl` (float): Realized profit or loss from position adjustments.\n  - `margin_mode` (`Order.margin_mode()`): Margin mode (e.g., `isolated`, `cross`).","ref":"Bingex.Swap.PositionUpdate.html#t:t/0"},{"type":"module","title":"Bingex.Swap.PriceEvent","doc":"Handles price events in BingX swaps.\n\nSupports last price and mark price updates.","ref":"Bingex.Swap.PriceEvent.html"},{"type":"function","title":"Bingex.Swap.PriceEvent.decode/1","doc":"","ref":"Bingex.Swap.PriceEvent.html#decode/1"},{"type":"type","title":"Bingex.Swap.PriceEvent.t/0","doc":"","ref":"Bingex.Swap.PriceEvent.html#t:t/0"},{"type":"behaviour","title":"Bingex.Swap.PriceSocket","doc":"```elixir\ndefmodule PriceSource do\n  use Bingex.Swap.PriceSocket\n  alias Bingex.Swap.PriceSocket\n\n  def start_link(_args \\\\ []) do\n    PriceSocket.start_link(__MODULE__, :state)\n  end\n\n  @impl true\n  def handle_connect(state) do\n    Process.flag(:trap_exit, true)\n    PriceSocket.subscribe(%{symbol: \"BTC-USDT\", type: :last})\n    {:ok, state}\n  end\n\n  @impl true\n  def handle_event(type, event, state) do\n    IO.inspect({type, event, state})\n    {:ok, state}\n  end\nend\n```","ref":"Bingex.Swap.PriceSocket.html"},{"type":"function","title":"Bingex.Swap.PriceSocket.call/3","doc":"","ref":"Bingex.Swap.PriceSocket.html#call/3"},{"type":"function","title":"Bingex.Swap.PriceSocket.cast/2","doc":"","ref":"Bingex.Swap.PriceSocket.html#cast/2"},{"type":"callback","title":"Bingex.Swap.PriceSocket.handle_event/3","doc":"","ref":"Bingex.Swap.PriceSocket.html#c:handle_event/3"},{"type":"function","title":"Bingex.Swap.PriceSocket.start/3","doc":"","ref":"Bingex.Swap.PriceSocket.html#start/3"},{"type":"function","title":"Bingex.Swap.PriceSocket.start_link/3","doc":"","ref":"Bingex.Swap.PriceSocket.html#start_link/3"},{"type":"function","title":"Bingex.Swap.PriceSocket.subscribe/2","doc":"","ref":"Bingex.Swap.PriceSocket.html#subscribe/2"},{"type":"module","title":"Bingex.Swap.QuoteInfo","doc":"Represents real-time quote information for a swap contract in BingX.\n\nThis module provides structured market data, including pricing and funding rate details.","ref":"Bingex.Swap.QuoteInfo.html"},{"type":"function","title":"Bingex.Swap.QuoteInfo.decode/1","doc":"","ref":"Bingex.Swap.QuoteInfo.html#decode/1"},{"type":"type","title":"Bingex.Swap.QuoteInfo.t/0","doc":"Quote information.\n\nFields:\n  - `symbol` (binary): Trading pair symbol (e.g., \"BTC-USDT\").\n  - `funding_rate` (float): Most recent funding rate applied to the contract.\n  - `next_funding_time` (integer): Timestamp of the next funding event.\n  - `mark_price` (float): Current mark price of the contract.\n  - `last_price` (float): Latest index price.","ref":"Bingex.Swap.QuoteInfo.html#t:t/0"},{"type":"module","title":"Bingex.Swap.SetLeverageData","doc":"Processes leverage setting response data for BingX swaps.\n\nExtracts margin details and converts raw API response into a structured format.","ref":"Bingex.Swap.SetLeverageData.html"},{"type":"function","title":"Bingex.Swap.SetLeverageData.decode/1","doc":"","ref":"Bingex.Swap.SetLeverageData.html#decode/1"},{"type":"function","title":"Bingex.Swap.SetLeverageData.embed_in_reply/1","doc":"","ref":"Bingex.Swap.SetLeverageData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.Swap.SetLeverageData.t/0","doc":"","ref":"Bingex.Swap.SetLeverageData.html#t:t/0"},{"type":"module","title":"Bingex.Swap.TradeEvent","doc":"Processes trade events in BingX swaps.\n\nExtracts order details, status, and execution information.","ref":"Bingex.Swap.TradeEvent.html"},{"type":"function","title":"Bingex.Swap.TradeEvent.decode/1","doc":"","ref":"Bingex.Swap.TradeEvent.html#decode/1"},{"type":"type","title":"Bingex.Swap.TradeEvent.t/0","doc":"","ref":"Bingex.Swap.TradeEvent.html#t:t/0"},{"type":"module","title":"Bingex.Swap.WalletUpdate","doc":"Represents a wallet balance update event for a swap account in BingX (ws event).\n\nThis module captures changes in wallet balance, including available funds and total balance.","ref":"Bingex.Swap.WalletUpdate.html"},{"type":"function","title":"Bingex.Swap.WalletUpdate.decode/1","doc":"","ref":"Bingex.Swap.WalletUpdate.html#decode/1"},{"type":"type","title":"Bingex.Swap.WalletUpdate.t/0","doc":"Wallet update information.\n\nFields:\n  - `asset` (binary): Asset symbol (e.g., \"USDT\").\n  - `balance_change` (float): Change in the wallet balance.\n  - `available_balance` (float): Updated available balance after the change.\n  - `balance` (float): Total balance after the update.","ref":"Bingex.Swap.WalletUpdate.html#t:t/0"},{"type":"module","title":"Bingex.User","doc":"Provides an interface to interact with the BingX User API.\n\nThis module enables users to manage authentication tokens, retrieve referral details, and handle account-related requests. It facilitates secure API interactions by generating and extending listen keys for user data streams and retrieving referral information.\n\nKey features:\n  - Generate and extend listen keys for user data streams\n  - Retrieve referral details for a specific user\n  - Fetch lists of referred users\n  - Secure request signing for authenticated API calls\n\nAll requests requiring authentication will be signed using an API key and secret key.","ref":"Bingex.User.html"},{"type":"function","title":"Bingex.User.extend_listen_key/2","doc":"","ref":"Bingex.User.html#extend_listen_key/2"},{"type":"function","title":"Bingex.User.generate_listen_key/1","doc":"","ref":"Bingex.User.html#generate_listen_key/1"},{"type":"function","title":"Bingex.User.get_referral/3","doc":"","ref":"Bingex.User.html#get_referral/3"},{"type":"function","title":"Bingex.User.get_referrals/6","doc":"","ref":"Bingex.User.html#get_referrals/6"},{"type":"module","title":"Bingex.User.GenerateListenKeyData","doc":"Represents the listen key data for user authentication in BingX.\n\nThis module structures and embeds the listen key response from the API, \nensuring proper decoding and integration within replies.","ref":"Bingex.User.GenerateListenKeyData.html"},{"type":"function","title":"Bingex.User.GenerateListenKeyData.decode/1","doc":"","ref":"Bingex.User.GenerateListenKeyData.html#decode/1"},{"type":"function","title":"Bingex.User.GenerateListenKeyData.embed_in_reply/1","doc":"","ref":"Bingex.User.GenerateListenKeyData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.User.GenerateListenKeyData.t/0","doc":"","ref":"Bingex.User.GenerateListenKeyData.html#t:t/0"},{"type":"module","title":"Bingex.User.GetReferralData","doc":"Retrieves and structures referral data for a user in BingX.\n\nThis module processes referral-related information from the API response, \nensuring correct decoding and embedding within replies.","ref":"Bingex.User.GetReferralData.html"},{"type":"function","title":"Bingex.User.GetReferralData.decode/1","doc":"","ref":"Bingex.User.GetReferralData.html#decode/1"},{"type":"function","title":"Bingex.User.GetReferralData.embed_in_reply/1","doc":"","ref":"Bingex.User.GetReferralData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.User.GetReferralData.t/0","doc":"","ref":"Bingex.User.GetReferralData.html#t:t/0"},{"type":"module","title":"Bingex.User.GetReferralsData","doc":"Retrieves and structures a list of referral data for a user in BingX.\n\nThis module processes multiple referral entries from the API response, \nensuring proper decoding and embedding within replies.","ref":"Bingex.User.GetReferralsData.html"},{"type":"function","title":"Bingex.User.GetReferralsData.decode/1","doc":"","ref":"Bingex.User.GetReferralsData.html#decode/1"},{"type":"function","title":"Bingex.User.GetReferralsData.embed_in_reply/1","doc":"","ref":"Bingex.User.GetReferralsData.html#embed_in_reply/1"},{"type":"type","title":"Bingex.User.GetReferralsData.t/0","doc":"","ref":"Bingex.User.GetReferralsData.html#t:t/0"},{"type":"module","title":"Bingex.User.ReferralInfo","doc":"Represents referral information for a user in BingX.\n\nThis module defines the structure and type for user referral data, \nproviding a function to decode API responses into a structured format.","ref":"Bingex.User.ReferralInfo.html"},{"type":"function","title":"Bingex.User.ReferralInfo.decode/1","doc":"","ref":"Bingex.User.ReferralInfo.html#decode/1"},{"type":"type","title":"Bingex.User.ReferralInfo.t/0","doc":"Referral information for a user.\n\nFields:\n  - `balance` - The total balance associated with the referral.\n  - `benefit_expiration` - The expiration timestamp of referral benefits.\n  - `benefit_ratio` - The benefit percentage received from the referral.\n  - `fee_ratio` - The commission fee ratio for the referral.\n  - `current_benefit` - The currently available benefit amount.\n  - `deposit?` - Indicates if the referred user has made a deposit.\n  - `direct_referral?` - Indicates if the referral is a direct invitation.\n  - `invite_code` - The invite code used for the referral.\n  - `invite_result` - Whether the invitation was successful.\n  - `inviter_sid` - The session ID of the inviter.\n  - `verified_kyc?` - Whether the referred user has completed KYC verification.\n  - `own_invite_code` - The referral’s own invite code.\n  - `registration_date` - The timestamp of the referral’s registration.\n  - `has_trades?` - Whether the referred user has executed any trades.\n  - `uid` - The unique identifier of the referred user.\n  - `user_level` - The current user level of the referral.","ref":"Bingex.User.ReferralInfo.html#t:t/0"},{"type":"exception","title":"Bingex.API.Error","doc":"Represents an error that occurs within the BingX API.\n\nThis module defines a custom exception struct for handling API-related errors,\nencapsulating the reason for the failure.","ref":"Bingex.API.Error.html"},{"type":"type","title":"Bingex.API.Error.t/0","doc":"","ref":"Bingex.API.Error.html#t:t/0"},{"type":"exception","title":"Bingex.HTTP.Error","doc":"Represents an HTTP error when communicating with the BingX API.\n\nThis module defines a custom exception for handling HTTP-related errors, \nencapsulating the reason for the failure.","ref":"Bingex.HTTP.Error.html"},{"type":"type","title":"Bingex.HTTP.Error.t/0","doc":"","ref":"Bingex.HTTP.Error.html#t:t/0"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}